@@ -1,3 +1,5 @@
+use crate::pda::PDA;
+
 use anchor_lang::prelude::*;
 use anchor_lang::AccountDeserialize;
 use std::convert::TryFrom;
@@ -18,3 +20,9 @@ impl TryFrom<Vec<u8>> for Fee {
         Fee::try_deserialize(&mut data.as_slice())
     }
 }
+
+impl Fee {
+    pub fn find_pda(daemon: Pubkey) -> PDA {
+        Pubkey::find_program_address(&[SEED_FEE, daemon.as_ref()], &crate::ID)
+    }
+}
