@@ -14,6 +14,19 @@ pub struct Health {
     pub bump: u8,
 }
 
+impl std::fmt::Display for Health {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        let drift = self.target_time - self.real_time;
+        write!(
+            f,
+            "Target ping: {}
+Last ping: {}
+Drift: {}",
+            self.target_time, self.real_time, drift,
+        )
+    }
+}
+
 impl TryFrom<Vec<u8>> for Health {
     type Error = ProgramError;
     fn try_from(data: Vec<u8>) -> Result<Self, Self::Error> {
